# Odin

**Odin** is an open-source CLI framework for managing big computer vision projects that are based on YOLO.

# Installation

```
pip install odin-vision
```

# Roadmap

Features planned for the next updates:

- [x] Automated dataset generation
- [x] Dataset versioning
- [x] Dataset rollback
- [x] Automated training
- [x] Model versioning
- [ ] Automated testing report generation
- [ ] Odin programmatic API
- [ ] Integration with PyTorch Lightning for performance